Pend

Enum Pend 

pub enum Pend {
    Idle = 0,
    Busy = 1,
}
Flash Pending. When Flash operation is in progress (busy), Flash reads and writes will fail. When PEND is set, write to all Flash registers, with exception of the Flash interrupt register, are ignored.

Value on reset: 0

Variants



Idle = 0

0: Idle.



Busy = 1

1: Busy.