EraseCodeR

Type Alias EraseCodeR 

pub type EraseCodeR = FieldReader<EraseCode>;
Field ERASE_CODE reader - Erase Code. The ERASE_CODE must be set up property before erase operation can be initiated. These bits are automatically cleared after the operation is complete.

Aliased Type

pub struct EraseCodeR { /* private fields */ }

Implementations

Source

impl EraseCodeR

pub const fn variant(&self) -> Option<EraseCode>

Get enumerated values variant

pub fn is_nop(&self) -> bool

No operation.

pub fn is_erase_page(&self) -> bool

Enable Page Erase.

pub fn is_erase_all(&self) -> bool

Enable Mass Erase. The debug port must be enabled.