R

Type Alias R 

pub type R = R<CtrlSpec>;
Register CTRL reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn wr(&self) -> WrR

Bit 0 - Write. This bit is automatically cleared after the operation.

pub fn me(&self) -> MeR

Bit 1 - Mass Erase. This bit is automatically cleared after the operation.

pub fn pge(&self) -> PgeR

Bit 2 - Page Erase. This bit is automatically cleared after the operation.

pub fn erase_code(&self) -> EraseCodeR

Bits 8:15 - Erase Code. The ERASE_CODE must be set up property before erase operation can be initiated. These bits are automatically cleared after the operation is complete.

pub fn pend(&self) -> PendR

Bit 24 - Flash Pending. When Flash operation is in progress (busy), Flash reads and writes will fail. When PEND is set, write to all Flash registers, with exception of the Flash interrupt register, are ignored.

pub fn lve(&self) -> LveR

Bit 25 - Low Voltage enable.

pub fn unlock(&self) -> UnlockR

Bits 28:31 - Flash Unlock. The correct unlock code must be written to these four bits before any Flash write or erase operation is allowed.