OneMstMode

Enum OneMstMode 

pub enum OneMstMode {
    Dis = 0,
    En = 1,
}
SCL Push-Pull Mode. This bit controls whether SCL is operated in a the I2C standard open-drain mode, or in a non-standard push-pull mode where the Hi-Z output isreplaced with Drive-1. The non-standard mode should only be used when operating as a master and communicating with slaves that are guaranteed to never drive SCL low.

Value on reset: 0

Variants



Dis = 0

0: Standard open-drain operation: drive low for 0, Hi-Z for 1



En = 1

1: Non-standard push-pull operation: drive low for 0, drive high for 1