RegisterBlock

Struct RegisterBlock 

pub struct RegisterBlock { /* private fields */ }
Register block

Implementations

Source

impl RegisterBlock

pub const fn lpcn(&self) -> &Lpcn

0x00 - Low Power Control Register.

pub const fn lpwkst0(&self) -> &Lpwkst0

0x04 - Low Power I/O Wakeup Status Register 0. This register indicates the low power wakeup status for GPIO0.

pub const fn lpwken0(&self) -> &Lpwken0

0x08 - Low Power I/O Wakeup Enable Register 0. This register enables low power wakeup functionality for GPIO0.

pub const fn lpwkst1(&self) -> &Lpwkst1

0x0c - Low Power I/O Wakeup Status Register 1. This register indicates the low power wakeup status for GPIO1.

pub const fn lpwken1(&self) -> &Lpwken1

0x10 - Low Power I/O Wakeup Enable Register 1. This register enables low power wakeup functionality for GPIO1.

pub const fn lpwkst2(&self) -> &Lpwkst2

0x14 - Low Power I/O Wakeup Status Register 2. This register indicates the low power wakeup status for GPIO2.

pub const fn lpwken2(&self) -> &Lpwken2

0x18 - Low Power I/O Wakeup Enable Register 2. This register enables low power wakeup functionality for GPIO2.

pub const fn lpwkst3(&self) -> &Lpwkst3

0x1c - Low Power I/O Wakeup Status Register 3. This register indicates the low power wakeup status for GPIO3.

pub const fn lpwken3(&self) -> &Lpwken3

0x20 - Low Power I/O Wakeup Enable Register 3. This register enables low power wakeup functionality for GPIO3.

pub const fn lppwst(&self) -> &Lppwst

0x30 - Low Power Peripheral Wakeup Status Register.

pub const fn lppwen(&self) -> &Lppwen

0x34 - Low Power Peripheral Wakeup Enable Register.

pub const fn gp0(&self) -> &Gp0

0x48 - General Purpose Register 0

pub const fn gp1(&self) -> &Gp1

0x4c - General Purpose Register 1