RegisterBlock

Struct RegisterBlock 

pub struct RegisterBlock { /* private fields */ }
Register block

Implementations

Source

impl RegisterBlock

pub const fn cnt(&self) -> &Cnt

0x00 - Count. This register stores the current timer count.

pub const fn cmp(&self) -> &Cmp

0x04 - Compare. This register stores the compare value, which is used to set the maximum count value to initiate a reload of the timer to 0x0001.

pub const fn intr(&self) -> &Intr

0x0c - Clear Interrupt. Writing a value (0 or 1) to a bit in this register clears the associated interrupt.

pub const fn ctrl(&self) -> &Ctrl

0x10 - Timer Control Register.

pub const fn nolcmp(&self) -> &Nolcmp

0x14 - Timer Non-Overlapping Compare Register.

pub const fn preset(&self) -> &Preset

0x18 - Preset register.

pub const fn reload(&self) -> &Reload

0x1c - Reload register.

pub const fn snapshot(&self) -> &Snapshot

0x20 - Snapshot register.