SrcSpec

Struct SrcSpec 

pub struct SrcSpec;
Source Device Address. If SRCINC=1, the counter bits are incremented by 1,2, or 4, depending on the data width of each AHB cycle. For peripheral transfers, some or all of the actual address bits are fixed. If SRCINC=0, this register remains constant. In the case where a count-to-zero condition occurs while RLDEN=1, the register is reloaded with the contents of DMA_SRC_RLD.

You can read this register and get src::R. You can reset, write, write_with_zero this register using src::W. You can also modify this register. See API.