#[repr(u8)]pub enum EraseCode {
Nop = 0,
ErasePage = 85,
EraseAll = 170,
}Expand description
Erase Code. The ERASE_CODE must be set up property before erase operation can be initiated. These bits are automatically cleared after the operation is complete.
Value on reset: 0
Variants
Nop = 0
0: No operation.
ErasePage = 85
85: Enable Page Erase.
EraseAll = 170
170: Enable Mass Erase. The debug port must be enabled.