pub enum Pend {
Idle = 0,
Busy = 1,
}Expand description
Flash Pending. When Flash operation is in progress (busy), Flash reads and writes will fail. When PEND is set, write to all Flash registers, with exception of the Flash interrupt register, are ignored.
Value on reset: 0
Variants