#[repr(u8)]pub enum Unlock {
Unlocked = 2,
Locked = 3,
}Expand description
Flash Unlock. The correct unlock code must be written to these four bits before any Flash write or erase operation is allowed.
Value on reset: 0
Variants