pub type EraseCodeR = FieldReader<EraseCode>;Expand description
Field ERASE_CODE reader - Erase Code. The ERASE_CODE must be set up property before erase operation can be initiated. These bits are automatically cleared after the operation is complete.
Aliased Type
pub struct EraseCodeR { /* private fields */ }