pub type R = R<CtrlSpec>;Expand description
Register CTRL reader
Aliased Type
pub struct R { /* private fields */ }Implementations
Sourceimpl R
impl R
Sourcepub fn me(&self) -> MeR
pub fn me(&self) -> MeR
Bit 1 - Mass Erase. This bit is automatically cleared after the operation.
Sourcepub fn pge(&self) -> PgeR
pub fn pge(&self) -> PgeR
Bit 2 - Page Erase. This bit is automatically cleared after the operation.
Sourcepub fn erase_code(&self) -> EraseCodeR
pub fn erase_code(&self) -> EraseCodeR
Bits 8:15 - Erase Code. The ERASE_CODE must be set up property before erase operation can be initiated. These bits are automatically cleared after the operation is complete.