pub struct RegisterBlock { /* private fields */ }Expand description
Register block
Implementations
Sourceimpl RegisterBlock
impl RegisterBlock
Sourcepub const fn clkdiv(&self) -> &Clkdiv
pub const fn clkdiv(&self) -> &Clkdiv
0x04 - Flash Clock Divide. The clock (PLL0) is divided by this value to generate a 1 MHz clock for Flash controller.
Sourcepub fn data_iter(&self) -> impl Iterator<Item = &Data>
pub fn data_iter(&self) -> impl Iterator<Item = &Data>
Iterator for array of: 0x30..0x40 - Flash Write Data.
Sourcepub const fn actrl(&self) -> &Actrl
pub const fn actrl(&self) -> &Actrl
0x40 - Access Control Register. Writing the ACTRL register with the following values in the order shown, allows read and write access to the system and user Information block: pflc-actrl = 0x3a7f5ca3; pflc-actrl = 0xa1e34f20; pflc-actrl = 0x9608b2c1. When unlocked, a write of any word will disable access to system and user information block. Readback of this register is always zero.