pub type W = W<CtrlSpec>;Expand description
Register CTRL writer
Aliased Type
pub struct W { /* private fields */ }Implementations
Sourceimpl W
impl W
Sourcepub fn en(&mut self) -> EnW<'_, CtrlSpec>
pub fn en(&mut self) -> EnW<'_, CtrlSpec>
Bit 0 - Real Time Clock Enable. This bit enables the Real Time Clock. This bit can only be written when WE=1 and BUSY =0. Change to this bit is effective only after BUSY is cleared from 1 to 0.
Sourcepub fn tod_alarm_ie(&mut self) -> TodAlarmIeW<'_, CtrlSpec>
pub fn tod_alarm_ie(&mut self) -> TodAlarmIeW<'_, CtrlSpec>
Bit 1 - Alarm Time-of-Day Interrupt Enable. Change to this bit is effective only after BUSY is cleared from 1 to 0.
Sourcepub fn ssec_alarm_ie(&mut self) -> SsecAlarmIeW<'_, CtrlSpec>
pub fn ssec_alarm_ie(&mut self) -> SsecAlarmIeW<'_, CtrlSpec>
Bit 2 - Alarm Sub-second Interrupt Enable. Change to this bit is effective only after BUSY is cleared from 1 to 0.
Sourcepub fn rdy(&mut self) -> RdyW<'_, CtrlSpec>
pub fn rdy(&mut self) -> RdyW<'_, CtrlSpec>
Bit 4 - RTC Ready. This bit is set to 1 by hardware when the RTC count registers update. It can be cleared to 0 by software at any time. It will also be cleared to 0 by hardware just prior to an update of the RTC count register.