pub type R = R<CtrlSpec>;Expand description
Register CTRL reader
Aliased Type
pub struct R { /* private fields */ }Implementations
Sourceimpl R
impl R
Sourcepub fn rx_thd_val(&self) -> RxThdValR
pub fn rx_thd_val(&self) -> RxThdValR
Bits 0:3 - This field specifies the depth of receive FIFO for interrupt generation (value 0 and > 16 are ignored)
Sourcepub fn par_eo(&self) -> ParEoR
pub fn par_eo(&self) -> ParEoR
Bit 5 - when PAREN=1 selects odd or even parity odd is 1 even is 0
Sourcepub fn tx_flush(&self) -> TxFlushR
pub fn tx_flush(&self) -> TxFlushR
Bit 8 - Flushes the TX FIFO buffer. This bit is automatically cleared by hardware when flush is completed.
Sourcepub fn rx_flush(&self) -> RxFlushR
pub fn rx_flush(&self) -> RxFlushR
Bit 9 - Flushes the RX FIFO buffer. This bit is automatically cleared by hardware when flush is completed.
Sourcepub fn stopbits(&self) -> StopbitsR
pub fn stopbits(&self) -> StopbitsR
Bit 12 - Selects the number of stop bits that will be generated