pub type W = W<CtrlSpec>;Expand description
Register CTRL writer
Aliased Type
pub struct W { /* private fields */ }Implementations
Sourceimpl W
impl W
Sourcepub fn rx_thd_val(&mut self) -> RxThdValW<'_, CtrlSpec>
pub fn rx_thd_val(&mut self) -> RxThdValW<'_, CtrlSpec>
Bits 0:3 - This field specifies the depth of receive FIFO for interrupt generation (value 0 and > 16 are ignored)
Sourcepub fn par_eo(&mut self) -> ParEoW<'_, CtrlSpec>
pub fn par_eo(&mut self) -> ParEoW<'_, CtrlSpec>
Bit 5 - when PAREN=1 selects odd or even parity odd is 1 even is 0
Sourcepub fn par_md(&mut self) -> ParMdW<'_, CtrlSpec>
pub fn par_md(&mut self) -> ParMdW<'_, CtrlSpec>
Bit 6 - Selects parity based on 1s or 0s count (when PAREN=1)
Sourcepub fn tx_flush(&mut self) -> TxFlushW<'_, CtrlSpec>
pub fn tx_flush(&mut self) -> TxFlushW<'_, CtrlSpec>
Bit 8 - Flushes the TX FIFO buffer. This bit is automatically cleared by hardware when flush is completed.
Sourcepub fn rx_flush(&mut self) -> RxFlushW<'_, CtrlSpec>
pub fn rx_flush(&mut self) -> RxFlushW<'_, CtrlSpec>
Bit 9 - Flushes the RX FIFO buffer. This bit is automatically cleared by hardware when flush is completed.
Sourcepub fn char_size(&mut self) -> CharSizeW<'_, CtrlSpec>
pub fn char_size(&mut self) -> CharSizeW<'_, CtrlSpec>
Bits 10:11 - Selects UART character size
Sourcepub fn stopbits(&mut self) -> StopbitsW<'_, CtrlSpec>
pub fn stopbits(&mut self) -> StopbitsW<'_, CtrlSpec>
Bit 12 - Selects the number of stop bits that will be generated
Sourcepub fn hfc_en(&mut self) -> HfcEnW<'_, CtrlSpec>
pub fn hfc_en(&mut self) -> HfcEnW<'_, CtrlSpec>
Bit 13 - Enables/disables hardware flow control
Sourcepub fn bclksrc(&mut self) -> BclksrcW<'_, CtrlSpec>
pub fn bclksrc(&mut self) -> BclksrcW<'_, CtrlSpec>
Bits 16:17 - To select the UART clock source for the UART engine (except APB registers). Secondary clock (used for baud rate generator) can be asynchronous from APB clock.