pub struct RegisterBlock { /* private fields */ }Expand description
Register block
Implementations
Sourceimpl RegisterBlock
impl RegisterBlock
Sourcepub const fn cmp(&self) -> &Cmp
pub const fn cmp(&self) -> &Cmp
0x04 - Compare. This register stores the compare value, which is used to set the maximum count value to initiate a reload of the timer to 0x0001.